# The client for remote calendars with builtin cache support

When you have a service that periodically runs, and you don't want to fetch a new version of your calendar each time, this is the go-to place. 

::: ical_library.CacheClient
